PAWpySeed: rayleigh_set Struct Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Attributes | List of all members
rayleigh_set Struct Reference

`#include <utils.h>`

## Public Attributes
int | l
| angular momentum quantum number More...
double complex * | terms
| rayleigh expansion terms More...

## Member Data Documentation

int rayleigh_set::l

angular momentum quantum number

double complex* rayleigh_set::terms

rayleigh expansion terms

The documentation for this struct was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/utils.h